@@ -85,11 +85,17 @@ def _get_by_runner_type(
         )
     elif identifier is RunnerType.SMDataParallel:
         return mpi.WorkerRunner(
-            user_entry_point, args, env_vars, processes_per_host, env.master_hostname
+            user_entry_point,
+            args,
+            env_vars,
+            processes_per_host,
+            env.master_hostname,
+            env.current_host,
         )
     elif identifier is RunnerType.MPI and env.is_master:
         num_processes = _mpi_param_value(mpi_args, env, params.MPI_NUM_PROCESSES)
         custom_mpi_options = _mpi_param_value(mpi_args, env, params.MPI_CUSTOM_OPTIONS, "")
+        current_instance_type = env.current_instance_type
         return mpi.MasterRunner(
             user_entry_point,
             args,
@@ -100,10 +106,16 @@ def _get_by_runner_type(
             custom_mpi_options,
             env.network_interface_name,
             num_processes=num_processes,
+            instance_type=current_instance_type,
         )
     elif identifier is RunnerType.MPI:
         return mpi.WorkerRunner(
-            user_entry_point, args, env_vars, processes_per_host, env.master_hostname
+            user_entry_point,
+            args,
+            env_vars,
+            processes_per_host,
+            env.master_hostname,
+            env.current_host,
         )
     elif identifier is RunnerType.PyTorchXLA:
         return pytorch_xla.PyTorchXLARunner(
